# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/slashing/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.slashing.v1beta1 import slashing_pb2 as cosmos_dot_slashing_dot_v1beta1_dot_slashing__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%cosmos/slashing/v1beta1/genesis.proto\x12\x17\x63osmos.slashing.v1beta1\x1a\x14gogoproto/gogo.proto\x1a&cosmos/slashing/v1beta1/slashing.proto\"\x85\x02\n\x0cGenesisState\x12\x35\n\x06params\x18\x01 \x01(\x0b\x32\x1f.cosmos.slashing.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\x12Y\n\rsigning_infos\x18\x02 \x03(\x0b\x32$.cosmos.slashing.v1beta1.SigningInfoB\x1c\xf2\xde\x1f\x14yaml:\"signing_infos\"\xc8\xde\x1f\x00\x12\x63\n\rmissed_blocks\x18\x03 \x03(\x0b\x32..cosmos.slashing.v1beta1.ValidatorMissedBlocksB\x1c\xf2\xde\x1f\x14yaml:\"missed_blocks\"\xc8\xde\x1f\x00\"\x94\x01\n\x0bSigningInfo\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12t\n\x16validator_signing_info\x18\x02 \x01(\x0b\x32-.cosmos.slashing.v1beta1.ValidatorSigningInfoB%\xc8\xde\x1f\x00\xf2\xde\x1f\x1dyaml:\"validator_signing_info\"\"\x83\x01\n\x15ValidatorMissedBlocks\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12Y\n\rmissed_blocks\x18\x02 \x03(\x0b\x32$.cosmos.slashing.v1beta1.MissedBlockB\x1c\xc8\xde\x1f\x00\xf2\xde\x1f\x14yaml:\"missed_blocks\"\",\n\x0bMissedBlock\x12\r\n\x05index\x18\x01 \x01(\x03\x12\x0e\n\x06missed\x18\x02 \x01(\x08\x42/Z-github.com/cosmos/cosmos-sdk/x/slashing/typesb\x06proto3')



_GENESISSTATE = DESCRIPTOR.message_types_by_name['GenesisState']
_SIGNINGINFO = DESCRIPTOR.message_types_by_name['SigningInfo']
_VALIDATORMISSEDBLOCKS = DESCRIPTOR.message_types_by_name['ValidatorMissedBlocks']
_MISSEDBLOCK = DESCRIPTOR.message_types_by_name['MissedBlock']
GenesisState = _reflection.GeneratedProtocolMessageType('GenesisState', (_message.Message,), {
  'DESCRIPTOR' : _GENESISSTATE,
  '__module__' : 'cosmos.slashing.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.slashing.v1beta1.GenesisState)
  })
_sym_db.RegisterMessage(GenesisState)

SigningInfo = _reflection.GeneratedProtocolMessageType('SigningInfo', (_message.Message,), {
  'DESCRIPTOR' : _SIGNINGINFO,
  '__module__' : 'cosmos.slashing.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.slashing.v1beta1.SigningInfo)
  })
_sym_db.RegisterMessage(SigningInfo)

ValidatorMissedBlocks = _reflection.GeneratedProtocolMessageType('ValidatorMissedBlocks', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATORMISSEDBLOCKS,
  '__module__' : 'cosmos.slashing.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.slashing.v1beta1.ValidatorMissedBlocks)
  })
_sym_db.RegisterMessage(ValidatorMissedBlocks)

MissedBlock = _reflection.GeneratedProtocolMessageType('MissedBlock', (_message.Message,), {
  'DESCRIPTOR' : _MISSEDBLOCK,
  '__module__' : 'cosmos.slashing.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.slashing.v1beta1.MissedBlock)
  })
_sym_db.RegisterMessage(MissedBlock)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/cosmos/cosmos-sdk/x/slashing/types'
  _GENESISSTATE.fields_by_name['params']._options = None
  _GENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['signing_infos']._options = None
  _GENESISSTATE.fields_by_name['signing_infos']._serialized_options = b'\362\336\037\024yaml:\"signing_infos\"\310\336\037\000'
  _GENESISSTATE.fields_by_name['missed_blocks']._options = None
  _GENESISSTATE.fields_by_name['missed_blocks']._serialized_options = b'\362\336\037\024yaml:\"missed_blocks\"\310\336\037\000'
  _SIGNINGINFO.fields_by_name['validator_signing_info']._options = None
  _SIGNINGINFO.fields_by_name['validator_signing_info']._serialized_options = b'\310\336\037\000\362\336\037\035yaml:\"validator_signing_info\"'
  _VALIDATORMISSEDBLOCKS.fields_by_name['missed_blocks']._options = None
  _VALIDATORMISSEDBLOCKS.fields_by_name['missed_blocks']._serialized_options = b'\310\336\037\000\362\336\037\024yaml:\"missed_blocks\"'
  _GENESISSTATE._serialized_start=129
  _GENESISSTATE._serialized_end=390
  _SIGNINGINFO._serialized_start=393
  _SIGNINGINFO._serialized_end=541
  _VALIDATORMISSEDBLOCKS._serialized_start=544
  _VALIDATORMISSEDBLOCKS._serialized_end=675
  _MISSEDBLOCK._serialized_start=677
  _MISSEDBLOCK._serialized_end=721
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/gov/v1beta1/gov.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63osmos/gov/v1beta1/gov.proto\x12\x12\x63osmos.gov.v1beta1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\"\x95\x01\n\x12WeightedVoteOption\x12.\n\x06option\x18\x01 \x01(\x0e\x32\x1e.cosmos.gov.v1beta1.VoteOption\x12O\n\x06weight\x18\x02 \x01(\tB?\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\xf2\xde\x1f\ryaml:\"weight\"\"C\n\x0cTextProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t:\x0f\xd2\xb4-\x07\x43ontent\xe8\xa0\x1f\x01\"\xb0\x01\n\x07\x44\x65posit\x12+\n\x0bproposal_id\x18\x01 \x01(\x04\x42\x16\xf2\xde\x1f\x12yaml:\"proposal_id\"\x12\x11\n\tdepositor\x18\x02 \x01(\t\x12[\n\x06\x61mount\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xfc\x05\n\x08Proposal\x12(\n\x0bproposal_id\x18\x01 \x01(\x04\x42\x13\xea\xde\x1f\x02id\xf2\xde\x1f\tyaml:\"id\"\x12\x32\n\x07\x63ontent\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\x0b\xca\xb4-\x07\x43ontent\x12N\n\x06status\x18\x03 \x01(\x0e\x32\".cosmos.gov.v1beta1.ProposalStatusB\x1a\xf2\xde\x1f\x16yaml:\"proposal_status\"\x12^\n\x12\x66inal_tally_result\x18\x04 \x01(\x0b\x32\x1f.cosmos.gov.v1beta1.TallyResultB!\xc8\xde\x1f\x00\xf2\xde\x1f\x19yaml:\"final_tally_result\"\x12O\n\x0bsubmit_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x1e\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x12yaml:\"submit_time\"\x12Y\n\x10\x64\x65posit_end_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB#\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x17yaml:\"deposit_end_time\"\x12z\n\rtotal_deposit\x18\x07 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBH\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x14yaml:\"total_deposit\"\x12[\n\x11voting_start_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB$\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x18yaml:\"voting_start_time\"\x12W\n\x0fvoting_end_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\"\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x16yaml:\"voting_end_time\":\x04\xe8\xa0\x1f\x01\"\xaa\x02\n\x0bTallyResult\x12;\n\x03yes\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12?\n\x07\x61\x62stain\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12:\n\x02no\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12[\n\x0cno_with_veto\x18\x04 \x01(\tBE\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\xf2\xde\x1f\x13yaml:\"no_with_veto\":\x04\xe8\xa0\x1f\x01\"\xbf\x01\n\x04Vote\x12+\n\x0bproposal_id\x18\x01 \x01(\x04\x42\x16\xf2\xde\x1f\x12yaml:\"proposal_id\"\x12\r\n\x05voter\x18\x02 \x01(\t\x12\x32\n\x06option\x18\x03 \x01(\x0e\x32\x1e.cosmos.gov.v1beta1.VoteOptionB\x02\x18\x01\x12=\n\x07options\x18\x04 \x03(\x0b\x32&.cosmos.gov.v1beta1.WeightedVoteOptionB\x04\xc8\xde\x1f\x00:\x08\x98\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x9f\x02\n\rDepositParams\x12\x8f\x01\n\x0bmin_deposit\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB_\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x12yaml:\"min_deposit\"\xea\xde\x1f\x15min_deposit,omitempty\x12|\n\x12max_deposit_period\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationBE\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xea\xde\x1f\x1cmax_deposit_period,omitempty\xf2\xde\x1f\x19yaml:\"max_deposit_period\"\"}\n\x0cVotingParams\x12m\n\rvoting_period\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB;\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xea\xde\x1f\x17voting_period,omitempty\xf2\xde\x1f\x14yaml:\"voting_period\"\"\xb8\x02\n\x0bTallyParams\x12R\n\x06quorum\x18\x01 \x01(\x0c\x42\x42\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\xea\xde\x1f\x10quorum,omitempty\x12X\n\tthreshold\x18\x02 \x01(\x0c\x42\x45\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\xea\xde\x1f\x13threshold,omitempty\x12{\n\x0eveto_threshold\x18\x03 \x01(\x0c\x42\x63\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\xea\xde\x1f\x18veto_threshold,omitempty\xf2\xde\x1f\x15yaml:\"veto_threshold\"*\xe6\x01\n\nVoteOption\x12,\n\x17VOTE_OPTION_UNSPECIFIED\x10\x00\x1a\x0f\x8a\x9d \x0bOptionEmpty\x12\"\n\x0fVOTE_OPTION_YES\x10\x01\x1a\r\x8a\x9d \tOptionYes\x12*\n\x13VOTE_OPTION_ABSTAIN\x10\x02\x1a\x11\x8a\x9d \rOptionAbstain\x12 \n\x0eVOTE_OPTION_NO\x10\x03\x1a\x0c\x8a\x9d \x08OptionNo\x12\x32\n\x18VOTE_OPTION_NO_WITH_VETO\x10\x04\x1a\x14\x8a\x9d \x10OptionNoWithVeto\x1a\x04\x88\xa3\x1e\x00*\xcc\x02\n\x0eProposalStatus\x12.\n\x1bPROPOSAL_STATUS_UNSPECIFIED\x10\x00\x1a\r\x8a\x9d \tStatusNil\x12;\n\x1ePROPOSAL_STATUS_DEPOSIT_PERIOD\x10\x01\x1a\x17\x8a\x9d \x13StatusDepositPeriod\x12\x39\n\x1dPROPOSAL_STATUS_VOTING_PERIOD\x10\x02\x1a\x16\x8a\x9d \x12StatusVotingPeriod\x12,\n\x16PROPOSAL_STATUS_PASSED\x10\x03\x1a\x10\x8a\x9d \x0cStatusPassed\x12\x30\n\x18PROPOSAL_STATUS_REJECTED\x10\x04\x1a\x12\x8a\x9d \x0eStatusRejected\x12,\n\x16PROPOSAL_STATUS_FAILED\x10\x05\x1a\x10\x8a\x9d \x0cStatusFailed\x1a\x04\x88\xa3\x1e\x00\x42\x36Z(github.com/cosmos/cosmos-sdk/x/gov/types\xd8\xe1\x1e\x00\x80\xe2\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3')

_VOTEOPTION = DESCRIPTOR.enum_types_by_name['VoteOption']
VoteOption = enum_type_wrapper.EnumTypeWrapper(_VOTEOPTION)
_PROPOSALSTATUS = DESCRIPTOR.enum_types_by_name['ProposalStatus']
ProposalStatus = enum_type_wrapper.EnumTypeWrapper(_PROPOSALSTATUS)
VOTE_OPTION_UNSPECIFIED = 0
VOTE_OPTION_YES = 1
VOTE_OPTION_ABSTAIN = 2
VOTE_OPTION_NO = 3
VOTE_OPTION_NO_WITH_VETO = 4
PROPOSAL_STATUS_UNSPECIFIED = 0
PROPOSAL_STATUS_DEPOSIT_PERIOD = 1
PROPOSAL_STATUS_VOTING_PERIOD = 2
PROPOSAL_STATUS_PASSED = 3
PROPOSAL_STATUS_REJECTED = 4
PROPOSAL_STATUS_FAILED = 5


_WEIGHTEDVOTEOPTION = DESCRIPTOR.message_types_by_name['WeightedVoteOption']
_TEXTPROPOSAL = DESCRIPTOR.message_types_by_name['TextProposal']
_DEPOSIT = DESCRIPTOR.message_types_by_name['Deposit']
_PROPOSAL = DESCRIPTOR.message_types_by_name['Proposal']
_TALLYRESULT = DESCRIPTOR.message_types_by_name['TallyResult']
_VOTE = DESCRIPTOR.message_types_by_name['Vote']
_DEPOSITPARAMS = DESCRIPTOR.message_types_by_name['DepositParams']
_VOTINGPARAMS = DESCRIPTOR.message_types_by_name['VotingParams']
_TALLYPARAMS = DESCRIPTOR.message_types_by_name['TallyParams']
WeightedVoteOption = _reflection.GeneratedProtocolMessageType('WeightedVoteOption', (_message.Message,), {
  'DESCRIPTOR' : _WEIGHTEDVOTEOPTION,
  '__module__' : 'cosmos.gov.v1beta1.gov_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.gov.v1beta1.WeightedVoteOption)
  })
_sym_db.RegisterMessage(WeightedVoteOption)

TextProposal = _reflection.GeneratedProtocolMessageType('TextProposal', (_message.Message,), {
  'DESCRIPTOR' : _TEXTPROPOSAL,
  '__module__' : 'cosmos.gov.v1beta1.gov_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.gov.v1beta1.TextProposal)
  })
_sym_db.RegisterMessage(TextProposal)

Deposit = _reflection.GeneratedProtocolMessageType('Deposit', (_message.Message,), {
  'DESCRIPTOR' : _DEPOSIT,
  '__module__' : 'cosmos.gov.v1beta1.gov_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.gov.v1beta1.Deposit)
  })
_sym_db.RegisterMessage(Deposit)

Proposal = _reflection.GeneratedProtocolMessageType('Proposal', (_message.Message,), {
  'DESCRIPTOR' : _PROPOSAL,
  '__module__' : 'cosmos.gov.v1beta1.gov_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.gov.v1beta1.Proposal)
  })
_sym_db.RegisterMessage(Proposal)

TallyResult = _reflection.GeneratedProtocolMessageType('TallyResult', (_message.Message,), {
  'DESCRIPTOR' : _TALLYRESULT,
  '__module__' : 'cosmos.gov.v1beta1.gov_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.gov.v1beta1.TallyResult)
  })
_sym_db.RegisterMessage(TallyResult)

Vote = _reflection.GeneratedProtocolMessageType('Vote', (_message.Message,), {
  'DESCRIPTOR' : _VOTE,
  '__module__' : 'cosmos.gov.v1beta1.gov_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.gov.v1beta1.Vote)
  })
_sym_db.RegisterMessage(Vote)

DepositParams = _reflection.GeneratedProtocolMessageType('DepositParams', (_message.Message,), {
  'DESCRIPTOR' : _DEPOSITPARAMS,
  '__module__' : 'cosmos.gov.v1beta1.gov_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.gov.v1beta1.DepositParams)
  })
_sym_db.RegisterMessage(DepositParams)

VotingParams = _reflection.GeneratedProtocolMessageType('VotingParams', (_message.Message,), {
  'DESCRIPTOR' : _VOTINGPARAMS,
  '__module__' : 'cosmos.gov.v1beta1.gov_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.gov.v1beta1.VotingParams)
  })
_sym_db.RegisterMessage(VotingParams)

TallyParams = _reflection.GeneratedProtocolMessageType('TallyParams', (_message.Message,), {
  'DESCRIPTOR' : _TALLYPARAMS,
  '__module__' : 'cosmos.gov.v1beta1.gov_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.gov.v1beta1.TallyParams)
  })
_sym_db.RegisterMessage(TallyParams)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z(github.com/cosmos/cosmos-sdk/x/gov/types\330\341\036\000\200\342\036\000\310\341\036\000'
  _VOTEOPTION._options = None
  _VOTEOPTION._serialized_options = b'\210\243\036\000'
  _VOTEOPTION.values_by_name["VOTE_OPTION_UNSPECIFIED"]._options = None
  _VOTEOPTION.values_by_name["VOTE_OPTION_UNSPECIFIED"]._serialized_options = b'\212\235 \013OptionEmpty'
  _VOTEOPTION.values_by_name["VOTE_OPTION_YES"]._options = None
  _VOTEOPTION.values_by_name["VOTE_OPTION_YES"]._serialized_options = b'\212\235 \tOptionYes'
  _VOTEOPTION.values_by_name["VOTE_OPTION_ABSTAIN"]._options = None
  _VOTEOPTION.values_by_name["VOTE_OPTION_ABSTAIN"]._serialized_options = b'\212\235 \rOptionAbstain'
  _VOTEOPTION.values_by_name["VOTE_OPTION_NO"]._options = None
  _VOTEOPTION.values_by_name["VOTE_OPTION_NO"]._serialized_options = b'\212\235 \010OptionNo'
  _VOTEOPTION.values_by_name["VOTE_OPTION_NO_WITH_VETO"]._options = None
  _VOTEOPTION.values_by_name["VOTE_OPTION_NO_WITH_VETO"]._serialized_options = b'\212\235 \020OptionNoWithVeto'
  _PROPOSALSTATUS._options = None
  _PROPOSALSTATUS._serialized_options = b'\210\243\036\000'
  _PROPOSALSTATUS.values_by_name["PROPOSAL_STATUS_UNSPECIFIED"]._options = None
  _PROPOSALSTATUS.values_by_name["PROPOSAL_STATUS_UNSPECIFIED"]._serialized_options = b'\212\235 \tStatusNil'
  _PROPOSALSTATUS.values_by_name["PROPOSAL_STATUS_DEPOSIT_PERIOD"]._options = None
  _PROPOSALSTATUS.values_by_name["PROPOSAL_STATUS_DEPOSIT_PERIOD"]._serialized_options = b'\212\235 \023StatusDepositPeriod'
  _PROPOSALSTATUS.values_by_name["PROPOSAL_STATUS_VOTING_PERIOD"]._options = None
  _PROPOSALSTATUS.values_by_name["PROPOSAL_STATUS_VOTING_PERIOD"]._serialized_options = b'\212\235 \022StatusVotingPeriod'
  _PROPOSALSTATUS.values_by_name["PROPOSAL_STATUS_PASSED"]._options = None
  _PROPOSALSTATUS.values_by_name["PROPOSAL_STATUS_PASSED"]._serialized_options = b'\212\235 \014StatusPassed'
  _PROPOSALSTATUS.values_by_name["PROPOSAL_STATUS_REJECTED"]._options = None
  _PROPOSALSTATUS.values_by_name["PROPOSAL_STATUS_REJECTED"]._serialized_options = b'\212\235 \016StatusRejected'
  _PROPOSALSTATUS.values_by_name["PROPOSAL_STATUS_FAILED"]._options = None
  _PROPOSALSTATUS.values_by_name["PROPOSAL_STATUS_FAILED"]._serialized_options = b'\212\235 \014StatusFailed'
  _WEIGHTEDVOTEOPTION.fields_by_name['weight']._options = None
  _WEIGHTEDVOTEOPTION.fields_by_name['weight']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000\362\336\037\ryaml:\"weight\"'
  _TEXTPROPOSAL._options = None
  _TEXTPROPOSAL._serialized_options = b'\322\264-\007Content\350\240\037\001'
  _DEPOSIT.fields_by_name['proposal_id']._options = None
  _DEPOSIT.fields_by_name['proposal_id']._serialized_options = b'\362\336\037\022yaml:\"proposal_id\"'
  _DEPOSIT.fields_by_name['amount']._options = None
  _DEPOSIT.fields_by_name['amount']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _DEPOSIT._options = None
  _DEPOSIT._serialized_options = b'\210\240\037\000\350\240\037\000'
  _PROPOSAL.fields_by_name['proposal_id']._options = None
  _PROPOSAL.fields_by_name['proposal_id']._serialized_options = b'\352\336\037\002id\362\336\037\tyaml:\"id\"'
  _PROPOSAL.fields_by_name['content']._options = None
  _PROPOSAL.fields_by_name['content']._serialized_options = b'\312\264-\007Content'
  _PROPOSAL.fields_by_name['status']._options = None
  _PROPOSAL.fields_by_name['status']._serialized_options = b'\362\336\037\026yaml:\"proposal_status\"'
  _PROPOSAL.fields_by_name['final_tally_result']._options = None
  _PROPOSAL.fields_by_name['final_tally_result']._serialized_options = b'\310\336\037\000\362\336\037\031yaml:\"final_tally_result\"'
  _PROPOSAL.fields_by_name['submit_time']._options = None
  _PROPOSAL.fields_by_name['submit_time']._serialized_options = b'\220\337\037\001\310\336\037\000\362\336\037\022yaml:\"submit_time\"'
  _PROPOSAL.fields_by_name['deposit_end_time']._options = None
  _PROPOSAL.fields_by_name['deposit_end_time']._serialized_options = b'\220\337\037\001\310\336\037\000\362\336\037\027yaml:\"deposit_end_time\"'
  _PROPOSAL.fields_by_name['total_deposit']._options = None
  _PROPOSAL.fields_by_name['total_deposit']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\362\336\037\024yaml:\"total_deposit\"'
  _PROPOSAL.fields_by_name['voting_start_time']._options = None
  _PROPOSAL.fields_by_name['voting_start_time']._serialized_options = b'\220\337\037\001\310\336\037\000\362\336\037\030yaml:\"voting_start_time\"'
  _PROPOSAL.fields_by_name['voting_end_time']._options = None
  _PROPOSAL.fields_by_name['voting_end_time']._serialized_options = b'\220\337\037\001\310\336\037\000\362\336\037\026yaml:\"voting_end_time\"'
  _PROPOSAL._options = None
  _PROPOSAL._serialized_options = b'\350\240\037\001'
  _TALLYRESULT.fields_by_name['yes']._options = None
  _TALLYRESULT.fields_by_name['yes']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _TALLYRESULT.fields_by_name['abstain']._options = None
  _TALLYRESULT.fields_by_name['abstain']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _TALLYRESULT.fields_by_name['no']._options = None
  _TALLYRESULT.fields_by_name['no']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _TALLYRESULT.fields_by_name['no_with_veto']._options = None
  _TALLYRESULT.fields_by_name['no_with_veto']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000\362\336\037\023yaml:\"no_with_veto\"'
  _TALLYRESULT._options = None
  _TALLYRESULT._serialized_options = b'\350\240\037\001'
  _VOTE.fields_by_name['proposal_id']._options = None
  _VOTE.fields_by_name['proposal_id']._serialized_options = b'\362\336\037\022yaml:\"proposal_id\"'
  _VOTE.fields_by_name['option']._options = None
  _VOTE.fields_by_name['option']._serialized_options = b'\030\001'
  _VOTE.fields_by_name['options']._options = None
  _VOTE.fields_by_name['options']._serialized_options = b'\310\336\037\000'
  _VOTE._options = None
  _VOTE._serialized_options = b'\230\240\037\000\350\240\037\000'
  _DEPOSITPARAMS.fields_by_name['min_deposit']._options = None
  _DEPOSITPARAMS.fields_by_name['min_deposit']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\362\336\037\022yaml:\"min_deposit\"\352\336\037\025min_deposit,omitempty'
  _DEPOSITPARAMS.fields_by_name['max_deposit_period']._options = None
  _DEPOSITPARAMS.fields_by_name['max_deposit_period']._serialized_options = b'\310\336\037\000\230\337\037\001\352\336\037\034max_deposit_period,omitempty\362\336\037\031yaml:\"max_deposit_period\"'
  _VOTINGPARAMS.fields_by_name['voting_period']._options = None
  _VOTINGPARAMS.fields_by_name['voting_period']._serialized_options = b'\310\336\037\000\230\337\037\001\352\336\037\027voting_period,omitempty\362\336\037\024yaml:\"voting_period\"'
  _TALLYPARAMS.fields_by_name['quorum']._options = None
  _TALLYPARAMS.fields_by_name['quorum']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000\352\336\037\020quorum,omitempty'
  _TALLYPARAMS.fields_by_name['threshold']._options = None
  _TALLYPARAMS.fields_by_name['threshold']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000\352\336\037\023threshold,omitempty'
  _TALLYPARAMS.fields_by_name['veto_threshold']._options = None
  _TALLYPARAMS.fields_by_name['veto_threshold']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000\352\336\037\030veto_threshold,omitempty\362\336\037\025yaml:\"veto_threshold\"'
  _VOTEOPTION._serialized_start=2620
  _VOTEOPTION._serialized_end=2850
  _PROPOSALSTATUS._serialized_start=2853
  _PROPOSALSTATUS._serialized_end=3185
  _WEIGHTEDVOTEOPTION._serialized_start=226
  _WEIGHTEDVOTEOPTION._serialized_end=375
  _TEXTPROPOSAL._serialized_start=377
  _TEXTPROPOSAL._serialized_end=444
  _DEPOSIT._serialized_start=447
  _DEPOSIT._serialized_end=623
  _PROPOSAL._serialized_start=626
  _PROPOSAL._serialized_end=1390
  _TALLYRESULT._serialized_start=1393
  _TALLYRESULT._serialized_end=1691
  _VOTE._serialized_start=1694
  _VOTE._serialized_end=1885
  _DEPOSITPARAMS._serialized_start=1888
  _DEPOSITPARAMS._serialized_end=2175
  _VOTINGPARAMS._serialized_start=2177
  _VOTINGPARAMS._serialized_end=2302
  _TALLYPARAMS._serialized_start=2305
  _TALLYPARAMS._serialized_end=2617
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/slashing/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.slashing.v1beta1 import slashing_pb2 as cosmos_dot_slashing_dot_v1beta1_dot_slashing__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cosmos/slashing/v1beta1/query.proto\x12\x17\x63osmos.slashing.v1beta1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a&cosmos/slashing/v1beta1/slashing.proto\"\x14\n\x12QueryParamsRequest\"L\n\x13QueryParamsResponse\x12\x35\n\x06params\x18\x01 \x01(\x0b\x32\x1f.cosmos.slashing.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\"/\n\x17QuerySigningInfoRequest\x12\x14\n\x0c\x63ons_address\x18\x01 \x01(\t\"i\n\x18QuerySigningInfoResponse\x12M\n\x10val_signing_info\x18\x01 \x01(\x0b\x32-.cosmos.slashing.v1beta1.ValidatorSigningInfoB\x04\xc8\xde\x1f\x00\"V\n\x18QuerySigningInfosRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x9b\x01\n\x19QuerySigningInfosResponse\x12\x41\n\x04info\x18\x01 \x03(\x0b\x32-.cosmos.slashing.v1beta1.ValidatorSigningInfoB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\xf2\x03\n\x05Query\x12\x8c\x01\n\x06Params\x12+.cosmos.slashing.v1beta1.QueryParamsRequest\x1a,.cosmos.slashing.v1beta1.QueryParamsResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/cosmos/slashing/v1beta1/params\x12\xb1\x01\n\x0bSigningInfo\x12\x30.cosmos.slashing.v1beta1.QuerySigningInfoRequest\x1a\x31.cosmos.slashing.v1beta1.QuerySigningInfoResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/cosmos/slashing/v1beta1/signing_infos/{cons_address}\x12\xa5\x01\n\x0cSigningInfos\x12\x31.cosmos.slashing.v1beta1.QuerySigningInfosRequest\x1a\x32.cosmos.slashing.v1beta1.QuerySigningInfosResponse\".\x82\xd3\xe4\x93\x02(\x12&/cosmos/slashing/v1beta1/signing_infosB/Z-github.com/cosmos/cosmos-sdk/x/slashing/typesb\x06proto3')



_QUERYPARAMSREQUEST = DESCRIPTOR.message_types_by_name['QueryParamsRequest']
_QUERYPARAMSRESPONSE = DESCRIPTOR.message_types_by_name['QueryParamsResponse']
_QUERYSIGNINGINFOREQUEST = DESCRIPTOR.message_types_by_name['QuerySigningInfoRequest']
_QUERYSIGNINGINFORESPONSE = DESCRIPTOR.message_types_by_name['QuerySigningInfoResponse']
_QUERYSIGNINGINFOSREQUEST = DESCRIPTOR.message_types_by_name['QuerySigningInfosRequest']
_QUERYSIGNINGINFOSRESPONSE = DESCRIPTOR.message_types_by_name['QuerySigningInfosResponse']
QueryParamsRequest = _reflection.GeneratedProtocolMessageType('QueryParamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSREQUEST,
  '__module__' : 'cosmos.slashing.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.slashing.v1beta1.QueryParamsRequest)
  })
_sym_db.RegisterMessage(QueryParamsRequest)

QueryParamsResponse = _reflection.GeneratedProtocolMessageType('QueryParamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSRESPONSE,
  '__module__' : 'cosmos.slashing.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.slashing.v1beta1.QueryParamsResponse)
  })
_sym_db.RegisterMessage(QueryParamsResponse)

QuerySigningInfoRequest = _reflection.GeneratedProtocolMessageType('QuerySigningInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSIGNINGINFOREQUEST,
  '__module__' : 'cosmos.slashing.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.slashing.v1beta1.QuerySigningInfoRequest)
  })
_sym_db.RegisterMessage(QuerySigningInfoRequest)

QuerySigningInfoResponse = _reflection.GeneratedProtocolMessageType('QuerySigningInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSIGNINGINFORESPONSE,
  '__module__' : 'cosmos.slashing.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.slashing.v1beta1.QuerySigningInfoResponse)
  })
_sym_db.RegisterMessage(QuerySigningInfoResponse)

QuerySigningInfosRequest = _reflection.GeneratedProtocolMessageType('QuerySigningInfosRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSIGNINGINFOSREQUEST,
  '__module__' : 'cosmos.slashing.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.slashing.v1beta1.QuerySigningInfosRequest)
  })
_sym_db.RegisterMessage(QuerySigningInfosRequest)

QuerySigningInfosResponse = _reflection.GeneratedProtocolMessageType('QuerySigningInfosResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSIGNINGINFOSRESPONSE,
  '__module__' : 'cosmos.slashing.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.slashing.v1beta1.QuerySigningInfosResponse)
  })
_sym_db.RegisterMessage(QuerySigningInfosResponse)

_QUERY = DESCRIPTOR.services_by_name['Query']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/cosmos/cosmos-sdk/x/slashing/types'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERYSIGNINGINFORESPONSE.fields_by_name['val_signing_info']._options = None
  _QUERYSIGNINGINFORESPONSE.fields_by_name['val_signing_info']._serialized_options = b'\310\336\037\000'
  _QUERYSIGNINGINFOSRESPONSE.fields_by_name['info']._options = None
  _QUERYSIGNINGINFOSRESPONSE.fields_by_name['info']._serialized_options = b'\310\336\037\000'
  _QUERY.methods_by_name['Params']._options = None
  _QUERY.methods_by_name['Params']._serialized_options = b'\202\323\344\223\002!\022\037/cosmos/slashing/v1beta1/params'
  _QUERY.methods_by_name['SigningInfo']._options = None
  _QUERY.methods_by_name['SigningInfo']._serialized_options = b'\202\323\344\223\0027\0225/cosmos/slashing/v1beta1/signing_infos/{cons_address}'
  _QUERY.methods_by_name['SigningInfos']._options = None
  _QUERY.methods_by_name['SigningInfos']._serialized_options = b'\202\323\344\223\002(\022&/cosmos/slashing/v1beta1/signing_infos'
  _QUERYPARAMSREQUEST._serialized_start=200
  _QUERYPARAMSREQUEST._serialized_end=220
  _QUERYPARAMSRESPONSE._serialized_start=222
  _QUERYPARAMSRESPONSE._serialized_end=298
  _QUERYSIGNINGINFOREQUEST._serialized_start=300
  _QUERYSIGNINGINFOREQUEST._serialized_end=347
  _QUERYSIGNINGINFORESPONSE._serialized_start=349
  _QUERYSIGNINGINFORESPONSE._serialized_end=454
  _QUERYSIGNINGINFOSREQUEST._serialized_start=456
  _QUERYSIGNINGINFOSREQUEST._serialized_end=542
  _QUERYSIGNINGINFOSRESPONSE._serialized_start=545
  _QUERYSIGNINGINFOSRESPONSE._serialized_end=700
  _QUERY._serialized_start=703
  _QUERY._serialized_end=1201
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from perp.v1 import query_pb2 as perp_dot_v1_dot_query__pb2


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Params = channel.unary_unary(
                '/nibiru.perp.v1.Query/Params',
                request_serializer=perp_dot_v1_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=perp_dot_v1_dot_query__pb2.QueryParamsResponse.FromString,
                )
        self.TraderPosition = channel.unary_unary(
                '/nibiru.perp.v1.Query/TraderPosition',
                request_serializer=perp_dot_v1_dot_query__pb2.QueryTraderPositionRequest.SerializeToString,
                response_deserializer=perp_dot_v1_dot_query__pb2.QueryTraderPositionResponse.FromString,
                )


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def Params(self, request, context):
        """Parameters queries the parameters of the x/perp module.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TraderPosition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=perp_dot_v1_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=perp_dot_v1_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'TraderPosition': grpc.unary_unary_rpc_method_handler(
                    servicer.TraderPosition,
                    request_deserializer=perp_dot_v1_dot_query__pb2.QueryTraderPositionRequest.FromString,
                    response_serializer=perp_dot_v1_dot_query__pb2.QueryTraderPositionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nibiru.perp.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.perp.v1.Query/Params',
            perp_dot_v1_dot_query__pb2.QueryParamsRequest.SerializeToString,
            perp_dot_v1_dot_query__pb2.QueryParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TraderPosition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.perp.v1.Query/TraderPosition',
            perp_dot_v1_dot_query__pb2.QueryTraderPositionRequest.SerializeToString,
            perp_dot_v1_dot_query__pb2.QueryTraderPositionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from vpool.v1 import query_pb2 as vpool_dot_v1_dot_query__pb2


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ReserveAssets = channel.unary_unary(
                '/nibiru.vpool.v1.Query/ReserveAssets',
                request_serializer=vpool_dot_v1_dot_query__pb2.QueryReserveAssetsRequest.SerializeToString,
                response_deserializer=vpool_dot_v1_dot_query__pb2.QueryReserveAssetsResponse.FromString,
                )
        self.AllPools = channel.unary_unary(
                '/nibiru.vpool.v1.Query/AllPools',
                request_serializer=vpool_dot_v1_dot_query__pb2.QueryAllPoolsRequest.SerializeToString,
                response_deserializer=vpool_dot_v1_dot_query__pb2.QueryAllPoolsResponse.FromString,
                )
        self.BaseAssetPrice = channel.unary_unary(
                '/nibiru.vpool.v1.Query/BaseAssetPrice',
                request_serializer=vpool_dot_v1_dot_query__pb2.QueryBaseAssetPriceRequest.SerializeToString,
                response_deserializer=vpool_dot_v1_dot_query__pb2.QueryBaseAssetPriceResponse.FromString,
                )


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def ReserveAssets(self, request, context):
        """Queries the reserve assets in a given pool, identified by a token pair.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AllPools(self, request, context):
        """Queries all virtual pools.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BaseAssetPrice(self, request, context):
        """Queries prices
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ReserveAssets': grpc.unary_unary_rpc_method_handler(
                    servicer.ReserveAssets,
                    request_deserializer=vpool_dot_v1_dot_query__pb2.QueryReserveAssetsRequest.FromString,
                    response_serializer=vpool_dot_v1_dot_query__pb2.QueryReserveAssetsResponse.SerializeToString,
            ),
            'AllPools': grpc.unary_unary_rpc_method_handler(
                    servicer.AllPools,
                    request_deserializer=vpool_dot_v1_dot_query__pb2.QueryAllPoolsRequest.FromString,
                    response_serializer=vpool_dot_v1_dot_query__pb2.QueryAllPoolsResponse.SerializeToString,
            ),
            'BaseAssetPrice': grpc.unary_unary_rpc_method_handler(
                    servicer.BaseAssetPrice,
                    request_deserializer=vpool_dot_v1_dot_query__pb2.QueryBaseAssetPriceRequest.FromString,
                    response_serializer=vpool_dot_v1_dot_query__pb2.QueryBaseAssetPriceResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nibiru.vpool.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def ReserveAssets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.vpool.v1.Query/ReserveAssets',
            vpool_dot_v1_dot_query__pb2.QueryReserveAssetsRequest.SerializeToString,
            vpool_dot_v1_dot_query__pb2.QueryReserveAssetsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AllPools(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.vpool.v1.Query/AllPools',
            vpool_dot_v1_dot_query__pb2.QueryAllPoolsRequest.SerializeToString,
            vpool_dot_v1_dot_query__pb2.QueryAllPoolsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BaseAssetPrice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.vpool.v1.Query/BaseAssetPrice',
            vpool_dot_v1_dot_query__pb2.QueryBaseAssetPriceRequest.SerializeToString,
            vpool_dot_v1_dot_query__pb2.QueryBaseAssetPriceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/upgrade/v1beta1/upgrade.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/upgrade/v1beta1/upgrade.proto\x12\x16\x63osmos.upgrade.v1beta1\x1a\x19google/protobuf/any.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xcb\x01\n\x04Plan\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x34\n\x04time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\x18\x01\x90\xdf\x1f\x01\xc8\xde\x1f\x00\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\x0c\n\x04info\x18\x04 \x01(\t\x12W\n\x15upgraded_client_state\x18\x05 \x01(\x0b\x32\x14.google.protobuf.AnyB\"\x18\x01\xf2\xde\x1f\x1cyaml:\"upgraded_client_state\":\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x00\"y\n\x17SoftwareUpgradeProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x30\n\x04plan\x18\x03 \x01(\x0b\x32\x1c.cosmos.upgrade.v1beta1.PlanB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x00\"M\n\x1d\x43\x61ncelSoftwareUpgradeProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t:\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x00\"8\n\rModuleVersion\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x04:\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x01\x42\x32Z,github.com/cosmos/cosmos-sdk/x/upgrade/types\xc8\xe1\x1e\x00\x62\x06proto3')



_PLAN = DESCRIPTOR.message_types_by_name['Plan']
_SOFTWAREUPGRADEPROPOSAL = DESCRIPTOR.message_types_by_name['SoftwareUpgradeProposal']
_CANCELSOFTWAREUPGRADEPROPOSAL = DESCRIPTOR.message_types_by_name['CancelSoftwareUpgradeProposal']
_MODULEVERSION = DESCRIPTOR.message_types_by_name['ModuleVersion']
Plan = _reflection.GeneratedProtocolMessageType('Plan', (_message.Message,), {
  'DESCRIPTOR' : _PLAN,
  '__module__' : 'cosmos.upgrade.v1beta1.upgrade_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.upgrade.v1beta1.Plan)
  })
_sym_db.RegisterMessage(Plan)

SoftwareUpgradeProposal = _reflection.GeneratedProtocolMessageType('SoftwareUpgradeProposal', (_message.Message,), {
  'DESCRIPTOR' : _SOFTWAREUPGRADEPROPOSAL,
  '__module__' : 'cosmos.upgrade.v1beta1.upgrade_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.upgrade.v1beta1.SoftwareUpgradeProposal)
  })
_sym_db.RegisterMessage(SoftwareUpgradeProposal)

CancelSoftwareUpgradeProposal = _reflection.GeneratedProtocolMessageType('CancelSoftwareUpgradeProposal', (_message.Message,), {
  'DESCRIPTOR' : _CANCELSOFTWAREUPGRADEPROPOSAL,
  '__module__' : 'cosmos.upgrade.v1beta1.upgrade_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.upgrade.v1beta1.CancelSoftwareUpgradeProposal)
  })
_sym_db.RegisterMessage(CancelSoftwareUpgradeProposal)

ModuleVersion = _reflection.GeneratedProtocolMessageType('ModuleVersion', (_message.Message,), {
  'DESCRIPTOR' : _MODULEVERSION,
  '__module__' : 'cosmos.upgrade.v1beta1.upgrade_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.upgrade.v1beta1.ModuleVersion)
  })
_sym_db.RegisterMessage(ModuleVersion)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z,github.com/cosmos/cosmos-sdk/x/upgrade/types\310\341\036\000'
  _PLAN.fields_by_name['time']._options = None
  _PLAN.fields_by_name['time']._serialized_options = b'\030\001\220\337\037\001\310\336\037\000'
  _PLAN.fields_by_name['upgraded_client_state']._options = None
  _PLAN.fields_by_name['upgraded_client_state']._serialized_options = b'\030\001\362\336\037\034yaml:\"upgraded_client_state\"'
  _PLAN._options = None
  _PLAN._serialized_options = b'\350\240\037\001\230\240\037\000'
  _SOFTWAREUPGRADEPROPOSAL.fields_by_name['plan']._options = None
  _SOFTWAREUPGRADEPROPOSAL.fields_by_name['plan']._serialized_options = b'\310\336\037\000'
  _SOFTWAREUPGRADEPROPOSAL._options = None
  _SOFTWAREUPGRADEPROPOSAL._serialized_options = b'\350\240\037\001\230\240\037\000'
  _CANCELSOFTWAREUPGRADEPROPOSAL._options = None
  _CANCELSOFTWAREUPGRADEPROPOSAL._serialized_options = b'\350\240\037\001\230\240\037\000'
  _MODULEVERSION._options = None
  _MODULEVERSION._serialized_options = b'\350\240\037\001\230\240\037\001'
  _PLAN._serialized_start=147
  _PLAN._serialized_end=350
  _SOFTWAREUPGRADEPROPOSAL._serialized_start=352
  _SOFTWAREUPGRADEPROPOSAL._serialized_end=473
  _CANCELSOFTWAREUPGRADEPROPOSAL._serialized_start=475
  _CANCELSOFTWAREUPGRADEPROPOSAL._serialized_end=552
  _MODULEVERSION._serialized_start=554
  _MODULEVERSION._serialized_end=610
# @@protoc_insertion_point(module_scope)



from typing import List

from nibiru.common import PoolAsset
from nibiru.proto.cosmos.base.v1beta1 import coin_pb2 as coin_pb
from nibiru.proto.dex.v1 import pool_pb2 as pool_tx_pb
from nibiru.proto.dex.v1 import tx_pb2 as dex_tx_pb
from nibiru.utils import float_to_sdkdec


class Dex:
    @staticmethod
    def create_pool(creator: str, swap_fee: float, exit_fee: float, assets: List[PoolAsset]):
        pool_assets = [pool_tx_pb.PoolAsset(token=a.token, weight=a.weight) for a in assets]
        swap_fee_dec = float_to_sdkdec(swap_fee)
        exit_fee_dec = float_to_sdkdec(exit_fee)
        return dex_tx_pb.MsgCreatePool(
            creator=creator,
            pool_params=pool_tx_pb.PoolParams(swapFee=swap_fee_dec, exitFee=exit_fee_dec),
            pool_assets=pool_assets,
        )

    @staticmethod
    def join_pool(sender: str, pool_id: int, tokens: List[coin_pb.Coin]):
        return dex_tx_pb.MsgJoinPool(
            sender=sender,
            pool_id=pool_id,
            tokens_in=tokens,
        )

    @staticmethod
    def exit_pool(sender: str, pool_id: int, pool_shares: coin_pb.Coin):
        return dex_tx_pb.MsgExitPool(
            sender=sender,
            pool_id=pool_id,
            pool_shares=pool_shares,
        )

    @staticmethod
    def swap_assets(sender: str, pool_id: int, token_in: coin_pb.Coin, token_out_denom):
        return dex_tx_pb.MsgSwapAssets(
            sender=sender,
            pool_id=pool_id,
            token_in=token_in,
            token_out_denom=token_out_denom,
        )



import unittest
from collections import namedtuple

from nibiru.exceptions import ConvertError, InvalidArgumentError
from nibiru.utils import float_to_sdkdec, sdkdec_to_float


class TestDecimals(unittest.TestCase):
    def test_to_dec(self):
        tc = namedtuple('testcase', 'name arg exp fail')
        tests = [
            tc('empty string', '', '', True),
            # valid numbers
            tc('number 0', 0, '0' + '0' * 18, False),
            tc('number 10', 10, '10' + '0' * 18, False),
            tc('number 123', 123, '123' + '0' * 18, False),
            tc('neg. number 123', -123, '-123' + '0' * 18, False),
            # with fractional
            tc('missing mantisse', 0.3, '03' + '0' * 17, False),
            tc('number 0.5', 0.5, '05' + '0' * 17, False),
            tc('number 13.235', 13.235, '13235' + '0' * 15, False),
            tc('neg. number 13.235', -13.235, '-13235' + '0' * 15, False),
            tc('number 1574.00005', 1574.00005, '157400005' + '0' * 13, False),
        ]

        for tt in tests:
            with self.subTest(tt.name):
                try:
                    res = float_to_sdkdec(tt.arg)
                    self.assertEqual(tt.exp, res)
                    self.assertFalse(tt.fail)
                except (InvalidArgumentError, ConvertError):
                    self.assertTrue(tt.fail)

    def test_from_dec(self):
        tc = namedtuple('testcase', 'name arg exp fail')
        tests = [
            tc('number with \'.\'', '.3', '', True),
            tc('number with \'.\'', '5.3', '', True),
            tc('invalid number', 'hello', '', True),
            # valid numbers
            tc('empty string', '', 0, False),
            tc('empty string', None, 0, False),
            tc('number 0', '0' * 5, 0, False),
            tc('number 0', '0' * 22, 0, False),
            tc('number 10', '10' + '0' * 18, 10, False),
            tc('neg. number 10', '-10' + '0' * 18, -10, False),
            tc('number 123', '123' + '0' * 18, 123, False),
            # with fractional
            tc('number 0.5', '05' + '0' * 17, 0.5, False),
            tc('fractional only 0.00596', '596' + '0' * 13, 0.00596, False),
            tc('number 13.5', '135' + '0' * 17, 13.5, False),
            tc('neg. number 13.5', '-135' + '0' * 17, -13.5, False),
            tc('number 1574.00005', '157400005' + '0' * 13, 1574.00005, False),
        ]

        for tt in tests:
            with self.subTest(tt.name):
                try:
                    res = sdkdec_to_float(tt.arg)
                    self.assertEqual(tt.exp, res)
                except (InvalidArgumentError, ConvertError):
                    self.assertTrue(tt.fail)


if __name__ == '__main__':
    unittest.main()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/bank/v1beta1/bank.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63osmos/bank/v1beta1/bank.proto\x12\x13\x63osmos.bank.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\xb2\x01\n\x06Params\x12Y\n\x0csend_enabled\x18\x01 \x03(\x0b\x32 .cosmos.bank.v1beta1.SendEnabledB!\xf2\xde\x1f\x1dyaml:\"send_enabled,omitempty\"\x12G\n\x14\x64\x65\x66\x61ult_send_enabled\x18\x02 \x01(\x08\x42)\xf2\xde\x1f%yaml:\"default_send_enabled,omitempty\":\x04\x98\xa0\x1f\x00\"7\n\x0bSendEnabled\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08:\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x00\"~\n\x05Input\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12Z\n\x05\x63oins\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x7f\n\x06Output\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12Z\n\x05\x63oins\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\xac\x01\n\x06Supply\x12Z\n\x05total\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:F\x18\x01\xe8\xa0\x1f\x01\x88\xa0\x1f\x00\xd2\xb4-8*github.com/cosmos/cosmos-sdk/x/bank/legacy/v040.SupplyI\"=\n\tDenomUnit\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x10\n\x08\x65xponent\x18\x02 \x01(\r\x12\x0f\n\x07\x61liases\x18\x03 \x03(\t\"\x91\x01\n\x08Metadata\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x33\n\x0b\x64\x65nom_units\x18\x02 \x03(\x0b\x32\x1e.cosmos.bank.v1beta1.DenomUnit\x12\x0c\n\x04\x62\x61se\x18\x03 \x01(\t\x12\x0f\n\x07\x64isplay\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0e\n\x06symbol\x18\x06 \x01(\tB+Z)github.com/cosmos/cosmos-sdk/x/bank/typesb\x06proto3')



_PARAMS = DESCRIPTOR.message_types_by_name['Params']
_SENDENABLED = DESCRIPTOR.message_types_by_name['SendEnabled']
_INPUT = DESCRIPTOR.message_types_by_name['Input']
_OUTPUT = DESCRIPTOR.message_types_by_name['Output']
_SUPPLY = DESCRIPTOR.message_types_by_name['Supply']
_DENOMUNIT = DESCRIPTOR.message_types_by_name['DenomUnit']
_METADATA = DESCRIPTOR.message_types_by_name['Metadata']
Params = _reflection.GeneratedProtocolMessageType('Params', (_message.Message,), {
  'DESCRIPTOR' : _PARAMS,
  '__module__' : 'cosmos.bank.v1beta1.bank_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.bank.v1beta1.Params)
  })
_sym_db.RegisterMessage(Params)

SendEnabled = _reflection.GeneratedProtocolMessageType('SendEnabled', (_message.Message,), {
  'DESCRIPTOR' : _SENDENABLED,
  '__module__' : 'cosmos.bank.v1beta1.bank_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.bank.v1beta1.SendEnabled)
  })
_sym_db.RegisterMessage(SendEnabled)

Input = _reflection.GeneratedProtocolMessageType('Input', (_message.Message,), {
  'DESCRIPTOR' : _INPUT,
  '__module__' : 'cosmos.bank.v1beta1.bank_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.bank.v1beta1.Input)
  })
_sym_db.RegisterMessage(Input)

Output = _reflection.GeneratedProtocolMessageType('Output', (_message.Message,), {
  'DESCRIPTOR' : _OUTPUT,
  '__module__' : 'cosmos.bank.v1beta1.bank_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.bank.v1beta1.Output)
  })
_sym_db.RegisterMessage(Output)

Supply = _reflection.GeneratedProtocolMessageType('Supply', (_message.Message,), {
  'DESCRIPTOR' : _SUPPLY,
  '__module__' : 'cosmos.bank.v1beta1.bank_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.bank.v1beta1.Supply)
  })
_sym_db.RegisterMessage(Supply)

DenomUnit = _reflection.GeneratedProtocolMessageType('DenomUnit', (_message.Message,), {
  'DESCRIPTOR' : _DENOMUNIT,
  '__module__' : 'cosmos.bank.v1beta1.bank_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.bank.v1beta1.DenomUnit)
  })
_sym_db.RegisterMessage(DenomUnit)

Metadata = _reflection.GeneratedProtocolMessageType('Metadata', (_message.Message,), {
  'DESCRIPTOR' : _METADATA,
  '__module__' : 'cosmos.bank.v1beta1.bank_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.bank.v1beta1.Metadata)
  })
_sym_db.RegisterMessage(Metadata)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/bank/types'
  _PARAMS.fields_by_name['send_enabled']._options = None
  _PARAMS.fields_by_name['send_enabled']._serialized_options = b'\362\336\037\035yaml:\"send_enabled,omitempty\"'
  _PARAMS.fields_by_name['default_send_enabled']._options = None
  _PARAMS.fields_by_name['default_send_enabled']._serialized_options = b'\362\336\037%yaml:\"default_send_enabled,omitempty\"'
  _PARAMS._options = None
  _PARAMS._serialized_options = b'\230\240\037\000'
  _SENDENABLED._options = None
  _SENDENABLED._serialized_options = b'\350\240\037\001\230\240\037\000'
  _INPUT.fields_by_name['coins']._options = None
  _INPUT.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _INPUT._options = None
  _INPUT._serialized_options = b'\350\240\037\000\210\240\037\000'
  _OUTPUT.fields_by_name['coins']._options = None
  _OUTPUT.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _OUTPUT._options = None
  _OUTPUT._serialized_options = b'\350\240\037\000\210\240\037\000'
  _SUPPLY.fields_by_name['total']._options = None
  _SUPPLY.fields_by_name['total']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _SUPPLY._options = None
  _SUPPLY._serialized_options = b'\030\001\350\240\037\001\210\240\037\000\322\264-8*github.com/cosmos/cosmos-sdk/x/bank/legacy/v040.SupplyI'
  _PARAMS._serialized_start=137
  _PARAMS._serialized_end=315
  _SENDENABLED._serialized_start=317
  _SENDENABLED._serialized_end=372
  _INPUT._serialized_start=374
  _INPUT._serialized_end=500
  _OUTPUT._serialized_start=502
  _OUTPUT._serialized_end=629
  _SUPPLY._serialized_start=632
  _SUPPLY._serialized_end=804
  _DENOMUNIT._serialized_start=806
  _DENOMUNIT._serialized_end=867
  _METADATA._serialized_start=870
  _METADATA._serialized_end=1015
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63ommon/common.proto\x12\rnibiru.common\x1a\x14gogoproto/gogo.proto\"1\n\tAssetPair\x12\x0e\n\x06token0\x18\x01 \x01(\t\x12\x0e\n\x06token1\x18\x02 \x01(\t:\x04\x88\xa0\x1f\x00\x42\x34Z&github.com/NibiruChain/nibiru/x/common\xa8\xe2\x1e\x01\xe0\xe1\x1e\x01\xd8\xe1\x1e\x00\x62\x06proto3')



_ASSETPAIR = DESCRIPTOR.message_types_by_name['AssetPair']
AssetPair = _reflection.GeneratedProtocolMessageType('AssetPair', (_message.Message,), {
  'DESCRIPTOR' : _ASSETPAIR,
  '__module__' : 'common.common_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.common.AssetPair)
  })
_sym_db.RegisterMessage(AssetPair)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z&github.com/NibiruChain/nibiru/x/common\250\342\036\001\340\341\036\001\330\341\036\000'
  _ASSETPAIR._options = None
  _ASSETPAIR._serialized_options = b'\210\240\037\000'
  _ASSETPAIR._serialized_start=60
  _ASSETPAIR._serialized_end=109
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: perp/v1/event.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from common import common_pb2 as common_dot_common__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from perp.v1 import state_pb2 as perp_dot_v1_dot_state__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x13perp/v1/event.proto\x12\x0enibiru.perp.v1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x13perp/v1/state.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x13\x63ommon/common.proto\"\x83\x07\n\x14PositionChangedEvent\x12\x0c\n\x04pair\x18\x01 \x01(\t\x12\x16\n\x0etrader_address\x18\x02 \x01(\t\x12@\n\x06margin\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x15\xf2\xde\x1f\ryaml:\"margin\"\xc8\xde\x1f\x00\x12I\n\x11position_notional\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12O\n\x17\x65xchanged_position_size\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12R\n\x0ftransaction_fee\x18\x06 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x1e\xf2\xde\x1f\x16yaml:\"transaction_fee\"\xc8\xde\x1f\x00\x12\x45\n\rposition_size\x18\x07 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x44\n\x0crealized_pnl\x18\x08 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12L\n\x14unrealized_pnl_after\x18\t \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x31\n\x08\x62\x61\x64_debt\x18\n \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12K\n\x13liquidation_penalty\x18\x0b \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x42\n\nspot_price\x18\x0c \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12G\n\x0f\x66unding_payment\x18\r \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x14\n\x0c\x62lock_height\x18\x0e \x01(\x03\x12\x15\n\rblock_time_ms\x18\x0f \x01(\x03\"\xf3\x06\n\x17PositionLiquidatedEvent\x12\x0c\n\x04pair\x18\x01 \x01(\t\x12\x16\n\x0etrader_address\x18\x02 \x01(\t\x12N\n\x16\x65xchanged_quote_amount\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12O\n\x17\x65xchanged_position_size\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x1a\n\x12liquidator_address\x18\x05 \x01(\t\x12V\n\x11\x66\x65\x65_to_liquidator\x18\x06 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB \xf2\xde\x1f\x18yaml:\"fee_to_liquidator\"\xc8\xde\x1f\x00\x12^\n\x15\x66\x65\x65_to_ecosystem_fund\x18\x07 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB$\xf2\xde\x1f\x1cyaml:\"fee_to_ecosystem_fund\"\xc8\xde\x1f\x00\x12\x31\n\x08\x62\x61\x64_debt\x18\x08 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12@\n\x06margin\x18\t \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x15\xf2\xde\x1f\ryaml:\"margin\"\xc8\xde\x1f\x00\x12I\n\x11position_notional\x18\n \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x45\n\rposition_size\x18\x0b \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x45\n\runrealizedPnl\x18\x0c \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x42\n\nmark_price\x18\r \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x14\n\x0c\x62lock_height\x18\x0e \x01(\x03\x12\x15\n\rblock_time_ms\x18\x0f \x01(\x03\"\xb8\x01\n\x14PositionSettledEvent\x12\x0c\n\x04pair\x18\x01 \x01(\t\x12\x16\n\x0etrader_address\x18\x02 \x01(\t\x12z\n\rsettled_coins\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBH\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x14yaml:\"settled_coins\"\xc8\xde\x1f\x00\"\xfb\x02\n\x17\x46undingRateChangedEvent\x12\x0c\n\x04pair\x18\x01 \x01(\t\x12\x42\n\nmark_price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x43\n\x0bindex_price\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12K\n\x13latest_funding_rate\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12O\n\x17\x63umulative_funding_rate\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x14\n\x0c\x62lock_height\x18\x06 \x01(\x03\x12\x15\n\rblock_time_ms\x18\x07 \x01(\x03\x42,Z*github.com/NibiruChain/nibiru/x/perp/typesb\x06proto3'
)


_POSITIONCHANGEDEVENT = DESCRIPTOR.message_types_by_name['PositionChangedEvent']
_POSITIONLIQUIDATEDEVENT = DESCRIPTOR.message_types_by_name['PositionLiquidatedEvent']
_POSITIONSETTLEDEVENT = DESCRIPTOR.message_types_by_name['PositionSettledEvent']
_FUNDINGRATECHANGEDEVENT = DESCRIPTOR.message_types_by_name['FundingRateChangedEvent']
PositionChangedEvent = _reflection.GeneratedProtocolMessageType(
    'PositionChangedEvent',
    (_message.Message,),
    {
        'DESCRIPTOR': _POSITIONCHANGEDEVENT,
        '__module__': 'perp.v1.event_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.perp.v1.PositionChangedEvent)
    },
)
_sym_db.RegisterMessage(PositionChangedEvent)

PositionLiquidatedEvent = _reflection.GeneratedProtocolMessageType(
    'PositionLiquidatedEvent',
    (_message.Message,),
    {
        'DESCRIPTOR': _POSITIONLIQUIDATEDEVENT,
        '__module__': 'perp.v1.event_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.perp.v1.PositionLiquidatedEvent)
    },
)
_sym_db.RegisterMessage(PositionLiquidatedEvent)

PositionSettledEvent = _reflection.GeneratedProtocolMessageType(
    'PositionSettledEvent',
    (_message.Message,),
    {
        'DESCRIPTOR': _POSITIONSETTLEDEVENT,
        '__module__': 'perp.v1.event_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.perp.v1.PositionSettledEvent)
    },
)
_sym_db.RegisterMessage(PositionSettledEvent)

FundingRateChangedEvent = _reflection.GeneratedProtocolMessageType(
    'FundingRateChangedEvent',
    (_message.Message,),
    {
        'DESCRIPTOR': _FUNDINGRATECHANGEDEVENT,
        '__module__': 'perp.v1.event_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.perp.v1.FundingRateChangedEvent)
    },
)
_sym_db.RegisterMessage(FundingRateChangedEvent)

if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z*github.com/NibiruChain/nibiru/x/perp/types'
    _POSITIONCHANGEDEVENT.fields_by_name['margin']._options = None
    _POSITIONCHANGEDEVENT.fields_by_name[
        'margin'
    ]._serialized_options = b'\362\336\037\ryaml:\"margin\"\310\336\037\000'
    _POSITIONCHANGEDEVENT.fields_by_name['position_notional']._options = None
    _POSITIONCHANGEDEVENT.fields_by_name[
        'position_notional'
    ]._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
    _POSITIONCHANGEDEVENT.fields_by_name['exchanged_position_size']._options = None
    _POSITIONCHANGEDEVENT.fields_by_name[
        'exchanged_position_size'
    ]._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
    _POSITIONCHANGEDEVENT.fields_by_name['transaction_fee']._options = None
    _POSITIONCHANGEDEVENT.fields_by_name[
        'transaction_fee'
    ]._serialized_options = b'\362\336\037\026yaml:\"transaction_fee\"\310\336\037\000'
    _POSITIONCHANGEDEVENT.fields_by_name['position_size']._options = None
    _POSITIONCHANGEDEVENT.fields_by_name[
        'position_size'
    ]._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
    _POSITIONCHANGEDEVENT.fields_by_name['realized_pnl']._options = None
    _POSITIONCHANGEDEVENT.fields_by_name[
        'realized_pnl'
    ]._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
    _POSITIONCHANGEDEVENT.fields_by_name['unrealized_pnl_after']._options = None
    _POSITIONCHANGEDEVENT.fields_by_name[
        'unrealized_pnl_after'
    ]._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
    _POSITIONCHANGEDEVENT.fields_by_name['bad_debt']._options = None
    _POSITIONCHANGEDEVENT.fields_by_name['bad_debt']._serialized_options = b'\310\336\037\000'
    _POSITIONCHANGEDEVENT.fields_by_name['liquidation_penalty']._options = None
    _POSITIONCHANGEDEVENT.fields_by_name[
        'liquidation_penalty'
    ]._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
    _POSITIONCHANGEDEVENT.fields_by_name['spot_price']._options = None
    _POSITIONCHANGEDEVENT.fields_by_name[
        'spot_price'
    ]._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
    _POSITIONCHANGEDEVENT.fields_by_name['funding_payment']._options = None
    _POSITIONCHANGEDEVENT.fields_by_name[
        'funding_payment'
    ]._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
    _POSITIONLIQUIDATEDEVENT.fields_by_name['exchanged_quote_amount']._options = None
    _POSITIONLIQUIDATEDEVENT.fields_by_name[
        'exchanged_quote_amount'
    ]._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
    _POSITIONLIQUIDATEDEVENT.fields_by_name['exchanged_position_size']._options = None
    _POSITIONLIQUIDATEDEVENT.fields_by_name[
        'exchanged_position_size'
    ]._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
    _POSITIONLIQUIDATEDEVENT.fields_by_name['fee_to_liquidator']._options = None
    _POSITIONLIQUIDATEDEVENT.fields_by_name[
        'fee_to_liquidator'
    ]._serialized_options = b'\362\336\037\030yaml:\"fee_to_liquidator\"\310\336\037\000'
    _POSITIONLIQUIDATEDEVENT.fields_by_name['fee_to_ecosystem_fund']._options = None
    _POSITIONLIQUIDATEDEVENT.fields_by_name[
        'fee_to_ecosystem_fund'
    ]._serialized_options = b'\362\336\037\034yaml:\"fee_to_ecosystem_fund\"\310\336\037\000'
    _POSITIONLIQUIDATEDEVENT.fields_by_name['bad_debt']._options = None
    _POSITIONLIQUIDATEDEVENT.fields_by_name['bad_debt']._serialized_options = b'\310\336\037\000'
    _POSITIONLIQUIDATEDEVENT.fields_by_name['margin']._options = None
    _POSITIONLIQUIDATEDEVENT.fields_by_name[
        'margin'
    ]._serialized_options = b'\362\336\037\ryaml:\"margin\"\310\336\037\000'
    _POSITIONLIQUIDATEDEVENT.fields_by_name['position_notional']._options = None
    _POSITIONLIQUIDATEDEVENT.fields_by_name[
        'position_notional'
    ]._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
    _POSITIONLIQUIDATEDEVENT.fields_by_name['position_size']._options = None
    _POSITIONLIQUIDATEDEVENT.fields_by_name[
        'position_size'
    ]._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
    _POSITIONLIQUIDATEDEVENT.fields_by_name['unrealizedPnl']._options = None
    _POSITIONLIQUIDATEDEVENT.fields_by_name[
        'unrealizedPnl'
    ]._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
    _POSITIONLIQUIDATEDEVENT.fields_by_name['mark_price']._options = None
    _POSITIONLIQUIDATEDEVENT.fields_by_name[
        'mark_price'
    ]._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
    _POSITIONSETTLEDEVENT.fields_by_name['settled_coins']._options = None
    _POSITIONSETTLEDEVENT.fields_by_name[
        'settled_coins'
    ]._serialized_options = (
        b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\362\336\037\024yaml:\"settled_coins\"\310\336\037\000'
    )
    _FUNDINGRATECHANGEDEVENT.fields_by_name['mark_price']._options = None
    _FUNDINGRATECHANGEDEVENT.fields_by_name[
        'mark_price'
    ]._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
    _FUNDINGRATECHANGEDEVENT.fields_by_name['index_price']._options = None
    _FUNDINGRATECHANGEDEVENT.fields_by_name[
        'index_price'
    ]._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
    _FUNDINGRATECHANGEDEVENT.fields_by_name['latest_funding_rate']._options = None
    _FUNDINGRATECHANGEDEVENT.fields_by_name[
        'latest_funding_rate'
    ]._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
    _FUNDINGRATECHANGEDEVENT.fields_by_name['cumulative_funding_rate']._options = None
    _FUNDINGRATECHANGEDEVENT.fields_by_name[
        'cumulative_funding_rate'
    ]._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
    _POSITIONCHANGEDEVENT._serialized_start = 166
    _POSITIONCHANGEDEVENT._serialized_end = 1065
    _POSITIONLIQUIDATEDEVENT._serialized_start = 1068
    _POSITIONLIQUIDATEDEVENT._serialized_end = 1951
    _POSITIONSETTLEDEVENT._serialized_start = 1954
    _POSITIONSETTLEDEVENT._serialized_end = 2138
    _FUNDINGRATECHANGEDEVENT._serialized_start = 2141
    _FUNDINGRATECHANGEDEVENT._serialized_end = 2520
# @@protoc_insertion_point(module_scope)



class NibiruError(Exception):
    pass


class ValueTooLargeError(NibiruError):
    pass


class EmptyMsgError(NibiruError):
    pass


class NotFoundError(NibiruError):
    pass


class UndefinedError(NibiruError):
    pass


class DecodeError(NibiruError):
    pass


class ConvertError(NibiruError):
    pass


class SchemaError(NibiruError):
    pass


class SimulationError(NibiruError):
    pass


class TxError(NibiruError):
    pass


class InvalidArgumentError(NibiruError):
    pass



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from perp.v1 import tx_pb2 as perp_dot_v1_dot_tx__pb2


class MsgStub(object):
    """Msg defines the x/perp Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RemoveMargin = channel.unary_unary(
                '/nibiru.perp.v1.Msg/RemoveMargin',
                request_serializer=perp_dot_v1_dot_tx__pb2.MsgRemoveMargin.SerializeToString,
                response_deserializer=perp_dot_v1_dot_tx__pb2.MsgRemoveMarginResponse.FromString,
                )
        self.AddMargin = channel.unary_unary(
                '/nibiru.perp.v1.Msg/AddMargin',
                request_serializer=perp_dot_v1_dot_tx__pb2.MsgAddMargin.SerializeToString,
                response_deserializer=perp_dot_v1_dot_tx__pb2.MsgAddMarginResponse.FromString,
                )
        self.Liquidate = channel.unary_unary(
                '/nibiru.perp.v1.Msg/Liquidate',
                request_serializer=perp_dot_v1_dot_tx__pb2.MsgLiquidate.SerializeToString,
                response_deserializer=perp_dot_v1_dot_tx__pb2.MsgLiquidateResponse.FromString,
                )
        self.OpenPosition = channel.unary_unary(
                '/nibiru.perp.v1.Msg/OpenPosition',
                request_serializer=perp_dot_v1_dot_tx__pb2.MsgOpenPosition.SerializeToString,
                response_deserializer=perp_dot_v1_dot_tx__pb2.MsgOpenPositionResponse.FromString,
                )
        self.ClosePosition = channel.unary_unary(
                '/nibiru.perp.v1.Msg/ClosePosition',
                request_serializer=perp_dot_v1_dot_tx__pb2.MsgClosePosition.SerializeToString,
                response_deserializer=perp_dot_v1_dot_tx__pb2.MsgClosePositionResponse.FromString,
                )


class MsgServicer(object):
    """Msg defines the x/perp Msg service.
    """

    def RemoveMargin(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddMargin(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Liquidate(self, request, context):
        """Liquidate is a transaction that allows the caller to fully or partially 
        liquidate an existing position. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OpenPosition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClosePosition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RemoveMargin': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveMargin,
                    request_deserializer=perp_dot_v1_dot_tx__pb2.MsgRemoveMargin.FromString,
                    response_serializer=perp_dot_v1_dot_tx__pb2.MsgRemoveMarginResponse.SerializeToString,
            ),
            'AddMargin': grpc.unary_unary_rpc_method_handler(
                    servicer.AddMargin,
                    request_deserializer=perp_dot_v1_dot_tx__pb2.MsgAddMargin.FromString,
                    response_serializer=perp_dot_v1_dot_tx__pb2.MsgAddMarginResponse.SerializeToString,
            ),
            'Liquidate': grpc.unary_unary_rpc_method_handler(
                    servicer.Liquidate,
                    request_deserializer=perp_dot_v1_dot_tx__pb2.MsgLiquidate.FromString,
                    response_serializer=perp_dot_v1_dot_tx__pb2.MsgLiquidateResponse.SerializeToString,
            ),
            'OpenPosition': grpc.unary_unary_rpc_method_handler(
                    servicer.OpenPosition,
                    request_deserializer=perp_dot_v1_dot_tx__pb2.MsgOpenPosition.FromString,
                    response_serializer=perp_dot_v1_dot_tx__pb2.MsgOpenPositionResponse.SerializeToString,
            ),
            'ClosePosition': grpc.unary_unary_rpc_method_handler(
                    servicer.ClosePosition,
                    request_deserializer=perp_dot_v1_dot_tx__pb2.MsgClosePosition.FromString,
                    response_serializer=perp_dot_v1_dot_tx__pb2.MsgClosePositionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nibiru.perp.v1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the x/perp Msg service.
    """

    @staticmethod
    def RemoveMargin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.perp.v1.Msg/RemoveMargin',
            perp_dot_v1_dot_tx__pb2.MsgRemoveMargin.SerializeToString,
            perp_dot_v1_dot_tx__pb2.MsgRemoveMarginResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddMargin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.perp.v1.Msg/AddMargin',
            perp_dot_v1_dot_tx__pb2.MsgAddMargin.SerializeToString,
            perp_dot_v1_dot_tx__pb2.MsgAddMarginResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Liquidate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.perp.v1.Msg/Liquidate',
            perp_dot_v1_dot_tx__pb2.MsgLiquidate.SerializeToString,
            perp_dot_v1_dot_tx__pb2.MsgLiquidateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OpenPosition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.perp.v1.Msg/OpenPosition',
            perp_dot_v1_dot_tx__pb2.MsgOpenPosition.SerializeToString,
            perp_dot_v1_dot_tx__pb2.MsgOpenPositionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClosePosition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.perp.v1.Msg/ClosePosition',
            perp_dot_v1_dot_tx__pb2.MsgClosePosition.SerializeToString,
            perp_dot_v1_dot_tx__pb2.MsgClosePositionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pricefeed/gov.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13pricefeed/gov.proto\x12\x13nibiru.pricefeed.v1\x1a\x14gogoproto/gogo.proto\"}\n\x11\x41\x64\x64OracleProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12#\n\x07oracles\x18\x03 \x03(\tB\x12\xf2\xde\x1f\x0eyaml:\"oracles\"\x12\x1f\n\x05pairs\x18\x04 \x03(\tB\x10\xf2\xde\x1f\x0cyaml:\"pairs\"B1Z/github.com/NibiruChain/nibiru/x/pricefeed/typesb\x06proto3')



_ADDORACLEPROPOSAL = DESCRIPTOR.message_types_by_name['AddOracleProposal']
AddOracleProposal = _reflection.GeneratedProtocolMessageType('AddOracleProposal', (_message.Message,), {
  'DESCRIPTOR' : _ADDORACLEPROPOSAL,
  '__module__' : 'pricefeed.gov_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.AddOracleProposal)
  })
_sym_db.RegisterMessage(AddOracleProposal)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/NibiruChain/nibiru/x/pricefeed/types'
  _ADDORACLEPROPOSAL.fields_by_name['oracles']._options = None
  _ADDORACLEPROPOSAL.fields_by_name['oracles']._serialized_options = b'\362\336\037\016yaml:\"oracles\"'
  _ADDORACLEPROPOSAL.fields_by_name['pairs']._options = None
  _ADDORACLEPROPOSAL.fields_by_name['pairs']._serialized_options = b'\362\336\037\014yaml:\"pairs\"'
  _ADDORACLEPROPOSAL._serialized_start=66
  _ADDORACLEPROPOSAL._serialized_end=191
# @@protoc_insertion_point(module_scope)



from nibiru.common import Side
from nibiru.proto.cosmos.base.v1beta1 import coin_pb2 as coin_pb
from nibiru.proto.perp.v1 import state_pb2 as state_pb
from nibiru.proto.perp.v1 import tx_pb2 as tx
from nibiru.utils import float_to_sdkdec, float_to_sdkint


class Perp:
    @staticmethod
    def remove_margin(sender: str, token_pair: str, margin: coin_pb.Coin):
        return tx.MsgRemoveMargin(
            sender=sender,
            token_pair=token_pair,
            margin=margin,
        )

    @staticmethod
    def add_margin(sender: str, token_pair: str, margin: coin_pb.Coin):
        return tx.MsgAddMargin(
            sender=sender,
            token_pair=token_pair,
            margin=margin,
        )

    @staticmethod
    def liquidate(sender: str, token_pair: str, trader: str):
        return tx.MsgLiquidate(
            sender=sender,
            token_pair=token_pair,
            trader=trader,
        )

    @staticmethod
    def open_position(
        sender: str,
        token_pair: str,
        side: Side,
        quote_asset_amount: float,
        leverage: float,
        base_asset_amount_limit: float,
    ):
        pb_side = state_pb.Side.BUY if side == Side.BUY else state_pb.SELL
        quote_asset_amount_pb = float_to_sdkint(quote_asset_amount)
        base_asset_amount_limit_pb = float_to_sdkint(base_asset_amount_limit)
        leverage_pb = float_to_sdkdec(leverage)
        return tx.MsgOpenPosition(
            sender=sender,
            token_pair=token_pair,
            side=pb_side,
            quote_asset_amount=quote_asset_amount_pb,
            leverage=leverage_pb,
            base_asset_amount_limit=base_asset_amount_limit_pb,
        )

    @staticmethod
    def close_position(sender: str, token_pair: str):
        return tx.MsgClosePosition(
            sender=sender,
            token_pair=token_pair,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/httpbody.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19google/api/httpbody.proto\x12\ngoogle.api\x1a\x19google/protobuf/any.proto\"X\n\x08HttpBody\x12\x14\n\x0c\x63ontent_type\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12(\n\nextensions\x18\x03 \x03(\x0b\x32\x14.google.protobuf.AnyBh\n\x0e\x63om.google.apiB\rHttpBodyProtoP\x01Z;google.golang.org/genproto/googleapis/api/httpbody;httpbody\xf8\x01\x01\xa2\x02\x04GAPIb\x06proto3')



_HTTPBODY = DESCRIPTOR.message_types_by_name['HttpBody']
HttpBody = _reflection.GeneratedProtocolMessageType('HttpBody', (_message.Message,), {
  'DESCRIPTOR' : _HTTPBODY,
  '__module__' : 'google.api.httpbody_pb2'
  # @@protoc_insertion_point(class_scope:google.api.HttpBody)
  })
_sym_db.RegisterMessage(HttpBody)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\016com.google.apiB\rHttpBodyProtoP\001Z;google.golang.org/genproto/googleapis/api/httpbody;httpbody\370\001\001\242\002\004GAPI'
  _HTTPBODY._serialized_start=68
  _HTTPBODY._serialized_end=156
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vpool/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from vpool.v1 import vpool_pb2 as vpool_dot_v1_dot_vpool__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14vpool/v1/query.proto\x12\x0fnibiru.vpool.v1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x14vpool/v1/vpool.proto\")\n\x19QueryReserveAssetsRequest\x12\x0c\n\x04pair\x18\x01 \x01(\t\"\xb5\x01\n\x1aQueryReserveAssetsResponse\x12J\n\x12\x62\x61se_asset_reserve\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12K\n\x13quote_asset_reserve\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\x16\n\x14QueryAllPoolsRequest\"=\n\x15QueryAllPoolsResponse\x12$\n\x05pools\x18\x01 \x03(\x0b\x32\x15.nibiru.vpool.v1.Pool\"\xa4\x01\n\x1aQueryBaseAssetPriceRequest\x12\x0c\n\x04pair\x18\x01 \x01(\t\x12-\n\tdirection\x18\x02 \x01(\x0e\x32\x1a.nibiru.vpool.v1.Direction\x12I\n\x11\x62\x61se_asset_amount\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"k\n\x1bQueryBaseAssetPriceResponse\x12L\n\x14price_in_quote_denom\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x32\xaa\x03\n\x05Query\x12\x8e\x01\n\rReserveAssets\x12*.nibiru.vpool.v1.QueryReserveAssetsRequest\x1a+.nibiru.vpool.v1.QueryReserveAssetsResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/nibiru/vpool/reserve_assets\x12z\n\x08\x41llPools\x12%.nibiru.vpool.v1.QueryAllPoolsRequest\x1a&.nibiru.vpool.v1.QueryAllPoolsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/nibiru/vpool/all_pools\x12\x93\x01\n\x0e\x42\x61seAssetPrice\x12+.nibiru.vpool.v1.QueryBaseAssetPriceRequest\x1a,.nibiru.vpool.v1.QueryBaseAssetPriceResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/nibiru/vpool/base_asset_priceB-Z+github.com/NibiruChain/nibiru/x/vpool/typesb\x06proto3')



_QUERYRESERVEASSETSREQUEST = DESCRIPTOR.message_types_by_name['QueryReserveAssetsRequest']
_QUERYRESERVEASSETSRESPONSE = DESCRIPTOR.message_types_by_name['QueryReserveAssetsResponse']
_QUERYALLPOOLSREQUEST = DESCRIPTOR.message_types_by_name['QueryAllPoolsRequest']
_QUERYALLPOOLSRESPONSE = DESCRIPTOR.message_types_by_name['QueryAllPoolsResponse']
_QUERYBASEASSETPRICEREQUEST = DESCRIPTOR.message_types_by_name['QueryBaseAssetPriceRequest']
_QUERYBASEASSETPRICERESPONSE = DESCRIPTOR.message_types_by_name['QueryBaseAssetPriceResponse']
QueryReserveAssetsRequest = _reflection.GeneratedProtocolMessageType('QueryReserveAssetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYRESERVEASSETSREQUEST,
  '__module__' : 'vpool.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.vpool.v1.QueryReserveAssetsRequest)
  })
_sym_db.RegisterMessage(QueryReserveAssetsRequest)

QueryReserveAssetsResponse = _reflection.GeneratedProtocolMessageType('QueryReserveAssetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYRESERVEASSETSRESPONSE,
  '__module__' : 'vpool.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.vpool.v1.QueryReserveAssetsResponse)
  })
_sym_db.RegisterMessage(QueryReserveAssetsResponse)

QueryAllPoolsRequest = _reflection.GeneratedProtocolMessageType('QueryAllPoolsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYALLPOOLSREQUEST,
  '__module__' : 'vpool.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.vpool.v1.QueryAllPoolsRequest)
  })
_sym_db.RegisterMessage(QueryAllPoolsRequest)

QueryAllPoolsResponse = _reflection.GeneratedProtocolMessageType('QueryAllPoolsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYALLPOOLSRESPONSE,
  '__module__' : 'vpool.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.vpool.v1.QueryAllPoolsResponse)
  })
_sym_db.RegisterMessage(QueryAllPoolsResponse)

QueryBaseAssetPriceRequest = _reflection.GeneratedProtocolMessageType('QueryBaseAssetPriceRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYBASEASSETPRICEREQUEST,
  '__module__' : 'vpool.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.vpool.v1.QueryBaseAssetPriceRequest)
  })
_sym_db.RegisterMessage(QueryBaseAssetPriceRequest)

QueryBaseAssetPriceResponse = _reflection.GeneratedProtocolMessageType('QueryBaseAssetPriceResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYBASEASSETPRICERESPONSE,
  '__module__' : 'vpool.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.vpool.v1.QueryBaseAssetPriceResponse)
  })
_sym_db.RegisterMessage(QueryBaseAssetPriceResponse)

_QUERY = DESCRIPTOR.services_by_name['Query']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/NibiruChain/nibiru/x/vpool/types'
  _QUERYRESERVEASSETSRESPONSE.fields_by_name['base_asset_reserve']._options = None
  _QUERYRESERVEASSETSRESPONSE.fields_by_name['base_asset_reserve']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _QUERYRESERVEASSETSRESPONSE.fields_by_name['quote_asset_reserve']._options = None
  _QUERYRESERVEASSETSRESPONSE.fields_by_name['quote_asset_reserve']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _QUERYBASEASSETPRICEREQUEST.fields_by_name['base_asset_amount']._options = None
  _QUERYBASEASSETPRICEREQUEST.fields_by_name['base_asset_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _QUERYBASEASSETPRICERESPONSE.fields_by_name['price_in_quote_denom']._options = None
  _QUERYBASEASSETPRICERESPONSE.fields_by_name['price_in_quote_denom']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _QUERY.methods_by_name['ReserveAssets']._options = None
  _QUERY.methods_by_name['ReserveAssets']._serialized_options = b'\202\323\344\223\002\036\022\034/nibiru/vpool/reserve_assets'
  _QUERY.methods_by_name['AllPools']._options = None
  _QUERY.methods_by_name['AllPools']._serialized_options = b'\202\323\344\223\002\031\022\027/nibiru/vpool/all_pools'
  _QUERY.methods_by_name['BaseAssetPrice']._options = None
  _QUERY.methods_by_name['BaseAssetPrice']._serialized_options = b'\202\323\344\223\002 \022\036/nibiru/vpool/base_asset_price'
  _QUERYRESERVEASSETSREQUEST._serialized_start=115
  _QUERYRESERVEASSETSREQUEST._serialized_end=156
  _QUERYRESERVEASSETSRESPONSE._serialized_start=159
  _QUERYRESERVEASSETSRESPONSE._serialized_end=340
  _QUERYALLPOOLSREQUEST._serialized_start=342
  _QUERYALLPOOLSREQUEST._serialized_end=364
  _QUERYALLPOOLSRESPONSE._serialized_start=366
  _QUERYALLPOOLSRESPONSE._serialized_end=427
  _QUERYBASEASSETPRICEREQUEST._serialized_start=430
  _QUERYBASEASSETPRICEREQUEST._serialized_end=594
  _QUERYBASEASSETPRICERESPONSE._serialized_start=596
  _QUERYBASEASSETPRICERESPONSE._serialized_end=703
  _QUERY._serialized_start=706
  _QUERY._serialized_end=1132
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dex/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from dex.v1 import params_pb2 as dex_dot_v1_dot_params__pb2
from dex.v1 import pool_pb2 as dex_dot_v1_dot_pool__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0f\x64\x65x/v1/tx.proto\x12\rnibiru.dex.v1\x1a\x13\x64\x65x/v1/params.proto\x1a\x11\x64\x65x/v1/pool.proto\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1cgoogle/api/annotations.proto\"\x9d\x01\n\rMsgCreatePool\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x46\n\x0bpool_params\x18\x02 \x01(\x0b\x32\x19.nibiru.dex.v1.PoolParamsB\x16\xf2\xde\x1f\x12yaml:\"pool_params\"\x12\x33\n\x0bpool_assets\x18\x03 \x03(\x0b\x32\x18.nibiru.dex.v1.PoolAssetB\x04\xc8\xde\x1f\x00\"(\n\x15MsgCreatePoolResponse\x12\x0f\n\x07pool_id\x18\x01 \x01(\x04\"\x9d\x01\n\x0bMsgJoinPool\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12#\n\x07pool_id\x18\x02 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12\x46\n\ttokens_in\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x18\xf2\xde\x1f\x10yaml:\"tokens_in\"\xc8\xde\x1f\x00\"\xe2\x01\n\x13MsgJoinPoolResponse\x12!\n\x04pool\x18\x01 \x01(\x0b\x32\x13.nibiru.dex.v1.Pool\x12Z\n\x13num_pool_shares_out\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\"\xf2\xde\x1f\x1ayaml:\"num_pool_shares_out\"\xc8\xde\x1f\x00\x12L\n\x0fremaining_coins\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x18\xf2\xde\x1f\x10yaml:\"tokens_in\"\xc8\xde\x1f\x00\"\xa1\x01\n\x0bMsgExitPool\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12#\n\x07pool_id\x18\x02 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12J\n\x0bpool_shares\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x1a\xf2\xde\x1f\x12yaml:\"pool_shares\"\xc8\xde\x1f\x00\"_\n\x13MsgExitPoolResponse\x12H\n\ntokens_out\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x19\xf2\xde\x1f\x11yaml:\"tokens_out\"\xc8\xde\x1f\x00\"\xd2\x01\n\rMsgSwapAssets\x12!\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"\x12#\n\x07pool_id\x18\x02 \x01(\x04\x42\x12\xf2\xde\x1f\x0eyaml:\"pool_id\"\x12\x44\n\x08token_in\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x17\xf2\xde\x1f\x0fyaml:\"token_in\"\xc8\xde\x1f\x00\x12\x33\n\x0ftoken_out_denom\x18\x04 \x01(\tB\x1a\xf2\xde\x1f\x16yaml:\"token_out_denom\"\"_\n\x15MsgSwapAssetsResponse\x12\x46\n\ttoken_out\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x18\xf2\xde\x1f\x10yaml:\"token_out\"\xc8\xde\x1f\x00\"\xd5\x01\n\x0f\x45ventPoolJoined\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0f\n\x07pool_id\x18\x02 \x01(\x04\x12\x32\n\ttokens_in\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12\x38\n\x0fpool_shares_out\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12\x32\n\trem_coins\x18\x05 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"4\n\x10\x45ventPoolCreated\x12\x0f\n\x07\x63reator\x18\x01 \x01(\t\x12\x0f\n\x07pool_id\x18\x02 \x01(\x04\"\xa1\x01\n\x0f\x45ventPoolExited\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0f\n\x07pool_id\x18\x02 \x01(\x04\x12\x37\n\x0epool_shares_in\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12\x33\n\ntokens_out\x18\x04 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\x9d\x01\n\x12\x45ventAssetsSwapped\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0f\n\x07pool_id\x18\x02 \x01(\x04\x12\x31\n\x08token_in\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12\x32\n\ttoken_out\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x32\xc7\x03\n\x03Msg\x12j\n\nCreatePool\x12\x1c.nibiru.dex.v1.MsgCreatePool\x1a$.nibiru.dex.v1.MsgCreatePoolResponse\"\x18\x82\xd3\xe4\x93\x02\x12\"\x10/nibiru/dex/pool\x12n\n\x08JoinPool\x12\x1a.nibiru.dex.v1.MsgJoinPool\x1a\".nibiru.dex.v1.MsgJoinPoolResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/nibiru/dex/{pool_id}/join\x12n\n\x08\x45xitPool\x12\x1a.nibiru.dex.v1.MsgExitPool\x1a\".nibiru.dex.v1.MsgExitPoolResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/nibiru/dex/{pool_id}/exit\x12t\n\nSwapAssets\x12\x1c.nibiru.dex.v1.MsgSwapAssets\x1a$.nibiru.dex.v1.MsgSwapAssetsResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/nibiru/dex/{pool_id}/swapB+Z)github.com/NibiruChain/nibiru/x/dex/typesb\x06proto3'
)


_MSGCREATEPOOL = DESCRIPTOR.message_types_by_name['MsgCreatePool']
_MSGCREATEPOOLRESPONSE = DESCRIPTOR.message_types_by_name['MsgCreatePoolResponse']
_MSGJOINPOOL = DESCRIPTOR.message_types_by_name['MsgJoinPool']
_MSGJOINPOOLRESPONSE = DESCRIPTOR.message_types_by_name['MsgJoinPoolResponse']
_MSGEXITPOOL = DESCRIPTOR.message_types_by_name['MsgExitPool']
_MSGEXITPOOLRESPONSE = DESCRIPTOR.message_types_by_name['MsgExitPoolResponse']
_MSGSWAPASSETS = DESCRIPTOR.message_types_by_name['MsgSwapAssets']
_MSGSWAPASSETSRESPONSE = DESCRIPTOR.message_types_by_name['MsgSwapAssetsResponse']
_EVENTPOOLJOINED = DESCRIPTOR.message_types_by_name['EventPoolJoined']
_EVENTPOOLCREATED = DESCRIPTOR.message_types_by_name['EventPoolCreated']
_EVENTPOOLEXITED = DESCRIPTOR.message_types_by_name['EventPoolExited']
_EVENTASSETSSWAPPED = DESCRIPTOR.message_types_by_name['EventAssetsSwapped']
MsgCreatePool = _reflection.GeneratedProtocolMessageType(
    'MsgCreatePool',
    (_message.Message,),
    {
        'DESCRIPTOR': _MSGCREATEPOOL,
        '__module__': 'dex.v1.tx_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.MsgCreatePool)
    },
)
_sym_db.RegisterMessage(MsgCreatePool)

MsgCreatePoolResponse = _reflection.GeneratedProtocolMessageType(
    'MsgCreatePoolResponse',
    (_message.Message,),
    {
        'DESCRIPTOR': _MSGCREATEPOOLRESPONSE,
        '__module__': 'dex.v1.tx_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.MsgCreatePoolResponse)
    },
)
_sym_db.RegisterMessage(MsgCreatePoolResponse)

MsgJoinPool = _reflection.GeneratedProtocolMessageType(
    'MsgJoinPool',
    (_message.Message,),
    {
        'DESCRIPTOR': _MSGJOINPOOL,
        '__module__': 'dex.v1.tx_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.MsgJoinPool)
    },
)
_sym_db.RegisterMessage(MsgJoinPool)

MsgJoinPoolResponse = _reflection.GeneratedProtocolMessageType(
    'MsgJoinPoolResponse',
    (_message.Message,),
    {
        'DESCRIPTOR': _MSGJOINPOOLRESPONSE,
        '__module__': 'dex.v1.tx_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.MsgJoinPoolResponse)
    },
)
_sym_db.RegisterMessage(MsgJoinPoolResponse)

MsgExitPool = _reflection.GeneratedProtocolMessageType(
    'MsgExitPool',
    (_message.Message,),
    {
        'DESCRIPTOR': _MSGEXITPOOL,
        '__module__': 'dex.v1.tx_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.MsgExitPool)
    },
)
_sym_db.RegisterMessage(MsgExitPool)

MsgExitPoolResponse = _reflection.GeneratedProtocolMessageType(
    'MsgExitPoolResponse',
    (_message.Message,),
    {
        'DESCRIPTOR': _MSGEXITPOOLRESPONSE,
        '__module__': 'dex.v1.tx_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.MsgExitPoolResponse)
    },
)
_sym_db.RegisterMessage(MsgExitPoolResponse)

MsgSwapAssets = _reflection.GeneratedProtocolMessageType(
    'MsgSwapAssets',
    (_message.Message,),
    {
        'DESCRIPTOR': _MSGSWAPASSETS,
        '__module__': 'dex.v1.tx_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.MsgSwapAssets)
    },
)
_sym_db.RegisterMessage(MsgSwapAssets)

MsgSwapAssetsResponse = _reflection.GeneratedProtocolMessageType(
    'MsgSwapAssetsResponse',
    (_message.Message,),
    {
        'DESCRIPTOR': _MSGSWAPASSETSRESPONSE,
        '__module__': 'dex.v1.tx_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.MsgSwapAssetsResponse)
    },
)
_sym_db.RegisterMessage(MsgSwapAssetsResponse)

EventPoolJoined = _reflection.GeneratedProtocolMessageType(
    'EventPoolJoined',
    (_message.Message,),
    {
        'DESCRIPTOR': _EVENTPOOLJOINED,
        '__module__': 'dex.v1.tx_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.EventPoolJoined)
    },
)
_sym_db.RegisterMessage(EventPoolJoined)

EventPoolCreated = _reflection.GeneratedProtocolMessageType(
    'EventPoolCreated',
    (_message.Message,),
    {
        'DESCRIPTOR': _EVENTPOOLCREATED,
        '__module__': 'dex.v1.tx_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.EventPoolCreated)
    },
)
_sym_db.RegisterMessage(EventPoolCreated)

EventPoolExited = _reflection.GeneratedProtocolMessageType(
    'EventPoolExited',
    (_message.Message,),
    {
        'DESCRIPTOR': _EVENTPOOLEXITED,
        '__module__': 'dex.v1.tx_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.EventPoolExited)
    },
)
_sym_db.RegisterMessage(EventPoolExited)

EventAssetsSwapped = _reflection.GeneratedProtocolMessageType(
    'EventAssetsSwapped',
    (_message.Message,),
    {
        'DESCRIPTOR': _EVENTASSETSSWAPPED,
        '__module__': 'dex.v1.tx_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.dex.v1.EventAssetsSwapped)
    },
)
_sym_db.RegisterMessage(EventAssetsSwapped)

_MSG = DESCRIPTOR.services_by_name['Msg']
if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z)github.com/NibiruChain/nibiru/x/dex/types'
    _MSGCREATEPOOL.fields_by_name['pool_params']._options = None
    _MSGCREATEPOOL.fields_by_name['pool_params']._serialized_options = b'\362\336\037\022yaml:\"pool_params\"'
    _MSGCREATEPOOL.fields_by_name['pool_assets']._options = None
    _MSGCREATEPOOL.fields_by_name['pool_assets']._serialized_options = b'\310\336\037\000'
    _MSGJOINPOOL.fields_by_name['sender']._options = None
    _MSGJOINPOOL.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
    _MSGJOINPOOL.fields_by_name['pool_id']._options = None
    _MSGJOINPOOL.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
    _MSGJOINPOOL.fields_by_name['tokens_in']._options = None
    _MSGJOINPOOL.fields_by_name['tokens_in']._serialized_options = b'\362\336\037\020yaml:\"tokens_in\"\310\336\037\000'
    _MSGJOINPOOLRESPONSE.fields_by_name['num_pool_shares_out']._options = None
    _MSGJOINPOOLRESPONSE.fields_by_name[
        'num_pool_shares_out'
    ]._serialized_options = b'\362\336\037\032yaml:\"num_pool_shares_out\"\310\336\037\000'
    _MSGJOINPOOLRESPONSE.fields_by_name['remaining_coins']._options = None
    _MSGJOINPOOLRESPONSE.fields_by_name[
        'remaining_coins'
    ]._serialized_options = b'\362\336\037\020yaml:\"tokens_in\"\310\336\037\000'
    _MSGEXITPOOL.fields_by_name['sender']._options = None
    _MSGEXITPOOL.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
    _MSGEXITPOOL.fields_by_name['pool_id']._options = None
    _MSGEXITPOOL.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
    _MSGEXITPOOL.fields_by_name['pool_shares']._options = None
    _MSGEXITPOOL.fields_by_name[
        'pool_shares'
    ]._serialized_options = b'\362\336\037\022yaml:\"pool_shares\"\310\336\037\000'
    _MSGEXITPOOLRESPONSE.fields_by_name['tokens_out']._options = None
    _MSGEXITPOOLRESPONSE.fields_by_name[
        'tokens_out'
    ]._serialized_options = b'\362\336\037\021yaml:\"tokens_out\"\310\336\037\000'
    _MSGSWAPASSETS.fields_by_name['sender']._options = None
    _MSGSWAPASSETS.fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
    _MSGSWAPASSETS.fields_by_name['pool_id']._options = None
    _MSGSWAPASSETS.fields_by_name['pool_id']._serialized_options = b'\362\336\037\016yaml:\"pool_id\"'
    _MSGSWAPASSETS.fields_by_name['token_in']._options = None
    _MSGSWAPASSETS.fields_by_name['token_in']._serialized_options = b'\362\336\037\017yaml:\"token_in\"\310\336\037\000'
    _MSGSWAPASSETS.fields_by_name['token_out_denom']._options = None
    _MSGSWAPASSETS.fields_by_name['token_out_denom']._serialized_options = b'\362\336\037\026yaml:\"token_out_denom\"'
    _MSGSWAPASSETSRESPONSE.fields_by_name['token_out']._options = None
    _MSGSWAPASSETSRESPONSE.fields_by_name[
        'token_out'
    ]._serialized_options = b'\362\336\037\020yaml:\"token_out\"\310\336\037\000'
    _EVENTPOOLJOINED.fields_by_name['tokens_in']._options = None
    _EVENTPOOLJOINED.fields_by_name['tokens_in']._serialized_options = b'\310\336\037\000'
    _EVENTPOOLJOINED.fields_by_name['pool_shares_out']._options = None
    _EVENTPOOLJOINED.fields_by_name['pool_shares_out']._serialized_options = b'\310\336\037\000'
    _EVENTPOOLJOINED.fields_by_name['rem_coins']._options = None
    _EVENTPOOLJOINED.fields_by_name['rem_coins']._serialized_options = b'\310\336\037\000'
    _EVENTPOOLEXITED.fields_by_name['pool_shares_in']._options = None
    _EVENTPOOLEXITED.fields_by_name['pool_shares_in']._serialized_options = b'\310\336\037\000'
    _EVENTPOOLEXITED.fields_by_name['tokens_out']._options = None
    _EVENTPOOLEXITED.fields_by_name['tokens_out']._serialized_options = b'\310\336\037\000'
    _EVENTASSETSSWAPPED.fields_by_name['token_in']._options = None
    _EVENTASSETSSWAPPED.fields_by_name['token_in']._serialized_options = b'\310\336\037\000'
    _EVENTASSETSSWAPPED.fields_by_name['token_out']._options = None
    _EVENTASSETSSWAPPED.fields_by_name['token_out']._serialized_options = b'\310\336\037\000'
    _MSG.methods_by_name['CreatePool']._options = None
    _MSG.methods_by_name['CreatePool']._serialized_options = b'\202\323\344\223\002\022\"\020/nibiru/dex/pool'
    _MSG.methods_by_name['JoinPool']._options = None
    _MSG.methods_by_name['JoinPool']._serialized_options = b'\202\323\344\223\002\034\"\032/nibiru/dex/{pool_id}/join'
    _MSG.methods_by_name['ExitPool']._options = None
    _MSG.methods_by_name['ExitPool']._serialized_options = b'\202\323\344\223\002\034\"\032/nibiru/dex/{pool_id}/exit'
    _MSG.methods_by_name['SwapAssets']._options = None
    _MSG.methods_by_name['SwapAssets']._serialized_options = b'\202\323\344\223\002\034\"\032/nibiru/dex/{pool_id}/swap'
    _MSGCREATEPOOL._serialized_start = 159
    _MSGCREATEPOOL._serialized_end = 316
    _MSGCREATEPOOLRESPONSE._serialized_start = 318
    _MSGCREATEPOOLRESPONSE._serialized_end = 358
    _MSGJOINPOOL._serialized_start = 361
    _MSGJOINPOOL._serialized_end = 518
    _MSGJOINPOOLRESPONSE._serialized_start = 521
    _MSGJOINPOOLRESPONSE._serialized_end = 747
    _MSGEXITPOOL._serialized_start = 750
    _MSGEXITPOOL._serialized_end = 911
    _MSGEXITPOOLRESPONSE._serialized_start = 913
    _MSGEXITPOOLRESPONSE._serialized_end = 1008
    _MSGSWAPASSETS._serialized_start = 1011
    _MSGSWAPASSETS._serialized_end = 1221
    _MSGSWAPASSETSRESPONSE._serialized_start = 1223
    _MSGSWAPASSETSRESPONSE._serialized_end = 1318
    _EVENTPOOLJOINED._serialized_start = 1321
    _EVENTPOOLJOINED._serialized_end = 1534
    _EVENTPOOLCREATED._serialized_start = 1536
    _EVENTPOOLCREATED._serialized_end = 1588
    _EVENTPOOLEXITED._serialized_start = 1591
    _EVENTPOOLEXITED._serialized_end = 1752
    _EVENTASSETSSWAPPED._serialized_start = 1755
    _EVENTASSETSSWAPPED._serialized_end = 1912
    _MSG._serialized_start = 1915
    _MSG._serialized_end = 2370
# @@protoc_insertion_point(module_scope)
